/*
 * configpanel.java
 *
 * Created on 29 January 2007, 19:26
 */

package gsm;

import gnu.io.CommPortIdentifier;
import gnu.io.NoSuchPortException;
import gnu.io.PortInUseException;
import gnu.io.SerialPort;
import java.awt.Dimension;
import java.awt.Toolkit;
import java.io.IOException;
import java.io.OutputStream;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.BufferedReader;
import java.io.PrintStream;
import java.io.File;
import java.io.FileOutputStream;
import java.util.Timer;
import javax.swing.ImageIcon;
import java.util.Date;
import java.util.Locale;
import java.text.SimpleDateFormat;

/**
 *
 * @author  JF Nutbroek - www.mywebmymail.com
 */
public class configpanel extends javax.swing.JFrame {

    private SerialPort serialPort;
    private CommPortIdentifier commPortId; 
    BufferedReader inStream = null;
    PrintStream outStream = null;  
    boolean communicating = false;
    
    /** Creates new form configpanel */
    public configpanel() {
        initComponents();
        // Add custom application icon
        ImageIcon app_icon = new ImageIcon(getClass().getResource("/images/icon.gif"));
        setIconImage(app_icon.getImage());
        // Center window 
        Toolkit kit = Toolkit.getDefaultToolkit();
        Dimension screenSize = kit.getScreenSize();
        int screenHeight = screenSize.height;
        int screenWidth = screenSize.width;
        this.setLocation((screenWidth-this.getWidth())/2,(screenHeight-this.getHeight())/2); 
    }
    
    public void readReply() {
        try {
            while (communicating) {try {Thread.sleep(100);} catch (InterruptedException e) {}}
            Thread thread = new Thread(longTask);
            thread.setPriority(Thread.NORM_PRIORITY);
            thread.start();
        } catch (Exception er) { 
            updatemessage("error");
        }
    }
    
    private Runnable longTask = new Runnable() {
        public void run() {
            try {
                communicating=true;
                get_GSM_answer();  
                communicating=false;
            } catch(Exception er) {
                communicating=false;
                updatemessage("unable to start RS232 session (read)");
            }
        }
    };      
    
    public void read_delayed_Reply() {
        try {
            Thread thread = new Thread(longTask_delayed);
            thread.setPriority(Thread.NORM_PRIORITY);
            thread.start();
        } catch (Exception er) { 
            updatemessage("error");
        }
    }
    
    private Runnable longTask_delayed = new Runnable() {
        public void run() {
            try {
                try {Thread.sleep(6500);} catch (InterruptedException e) {}
                readReply(); 
                try {Thread.sleep(10500);} catch (InterruptedException e) {}
                readReply();                 
            } catch(Exception er) {
                updatemessage("unable to start RS232 session (read)");
            }
        }
    };        
    
    public void initializeCOM() {
        closeCOM();
        try {
            commPortId = CommPortIdentifier.getPortIdentifier("COM" + comport.getText().toString());
            serialPort = (SerialPort)commPortId.open("COM" + comport.getText().toString(),0);
            serialPort.setSerialPortParams(9600,SerialPort.DATABITS_8,SerialPort.STOPBITS_1,SerialPort.PARITY_NONE); 
            serialPort.setFlowControlMode(SerialPort.FLOWCONTROL_NONE);
            try {
                inStream = new BufferedReader(new InputStreamReader(serialPort.getInputStream()));
            } catch (IOException e) {
                inStream = null;
            }
            if (inStream == null) {
                throw new NoSuchPortException();
            } else {
                outStream = new PrintStream(serialPort.getOutputStream(), true);            
            }
        } catch (PortInUseException e) {
            updatemessage("Error: Port " + "COM" + comport.getText().toString() + " already in use");
            closeCOM();
        } catch (NoSuchPortException e) {
            updatemessage("Error: Port " + "COM" + comport.getText().toString() + " does not exist");
            closeCOM();
        } catch (Exception e) { 
            updatemessage("RS232 communication error");
            closeCOM();
        } finally {
            this.setTitle("GSM Configurator - Version 1.0.1");
        }           
    }
    
    public void closeCOM() {
        try {
            if (inStream != null)
                inStream.close();
            if (outStream != null)
                outStream.close();
            if (serialPort != null)
                serialPort.close();            
        } catch (IOException e) {}
        inStream = null;
        outStream = null;
        serialPort = null;
        commPortId = null;        
    }
    
    public void sendCommand(String command) {
        try {
            while (communicating) {try {Thread.sleep(100);} catch (InterruptedException e) {}}
            outStream.print(command);
            outStream.print("\r\n");        
        } catch (Exception e) {updatemessage("unable to send command");}
    }
    
    public void get_GSM_answer() {
        long timer=System.currentTimeMillis();
        String reply="";     
        while ((System.currentTimeMillis()-timer)<2000 && !reply.equals("OK") && !reply.equals("ERROR") && !reply.equals("0") && !reply.equals("4")) {
            try {
                while (!inStream.ready() && (System.currentTimeMillis()-timer)<2000) {
                    try {Thread.sleep(100);} catch (InterruptedException e) {}
                }
            } catch (Exception e) {}
            try {
                if (inStream.ready()) {
                    reply = inStream.readLine().toString();
                    if (!reply.equals("")) {updatemessage(reply);}
                }
            } catch (Exception e) {}
        }
    }    
     
    public void updatemessage(String text) {
        text.replace("\u001A","");
        message.append(">" + text);
        message.append("\r");
        message.append("\n");
        message.setCaretPosition(message.getDocument().getLength());
    }
    
    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:initComponents
    private void initComponents() {
        jPanel1 = new javax.swing.JPanel();
        jScrollPane1 = new javax.swing.JScrollPane();
        message = new javax.swing.JTextArea();
        jLabel5 = new javax.swing.JLabel();
        comport = new javax.swing.JTextField();
        up = new javax.swing.JButton();
        down = new javax.swing.JButton();
        atf = new javax.swing.JButton();
        atv = new javax.swing.JButton();
        atx = new javax.swing.JButton();
        atd = new javax.swing.JButton();
        ats = new javax.swing.JButton();
        atw = new javax.swing.JButton();
        atcmgf = new javax.swing.JButton();
        command = new javax.swing.JTextField();
        atcommand = new javax.swing.JButton();
        pin = new javax.swing.JButton();
        pincode = new javax.swing.JTextField();
        puc = new javax.swing.JButton();
        puccode = new javax.swing.JTextField();
        autocops = new javax.swing.JButton();
        disablecops = new javax.swing.JButton();
        atd2 = new javax.swing.JButton();
        atcops = new javax.swing.JButton();
        jLabel6 = new javax.swing.JLabel();
        phonenumber = new javax.swing.JTextField();
        jLabel7 = new javax.swing.JLabel();
        smsmessage = new javax.swing.JTextField();
        sendsms = new javax.swing.JButton();
        servicecenterphonenumber = new javax.swing.JTextField();
        servicephone = new javax.swing.JButton();
        autopin = new javax.swing.JButton();
        autocfun = new javax.swing.JButton();
        disablepin = new javax.swing.JButton();
        disablecfun = new javax.swing.JButton();
        powerdown = new javax.swing.JButton();
        ssmss = new javax.swing.JButton();
        atcmgl = new javax.swing.JButton();

        setDefaultCloseOperation(javax.swing.WindowConstants.EXIT_ON_CLOSE);
        setTitle("GSM Configurator - Initializing...");
        setResizable(false);
        addWindowListener(new java.awt.event.WindowAdapter() {
            public void windowClosing(java.awt.event.WindowEvent evt) {
                formWindowClosing(evt);
            }
            public void windowOpened(java.awt.event.WindowEvent evt) {
                formWindowOpened(evt);
            }
        });

        jScrollPane1.setHorizontalScrollBarPolicy(javax.swing.ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER);
        jScrollPane1.setVerticalScrollBarPolicy(javax.swing.ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS);
        jScrollPane1.setMaximumSize(new java.awt.Dimension(320, 250));
        jScrollPane1.setMinimumSize(new java.awt.Dimension(320, 250));
        message.setBackground(new java.awt.Color(0, 0, 0));
        message.setFont(new java.awt.Font("Dialog", 0, 10));
        message.setForeground(new java.awt.Color(255, 255, 255));
        message.setLineWrap(true);
        message.setToolTipText("");
        message.setAutoscrolls(false);
        message.setDisabledTextColor(new java.awt.Color(255, 255, 255));
        message.setEnabled(false);
        message.setMaximumSize(new java.awt.Dimension(280, 250));
        message.setMinimumSize(new java.awt.Dimension(280, 250));
        jScrollPane1.setViewportView(message);

        jLabel5.setText("COM port");

        comport.setEditable(false);
        comport.setHorizontalAlignment(javax.swing.JTextField.CENTER);
        comport.setText("1");
        comport.setToolTipText("Number of the COM port");

        up.setIcon(new javax.swing.ImageIcon(getClass().getResource("/images/up.gif")));
        up.setToolTipText("up");
        up.setBorder(null);
        up.setBorderPainted(false);
        up.setContentAreaFilled(false);
        up.setFocusPainted(false);
        up.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                upActionPerformed(evt);
            }
        });

        down.setIcon(new javax.swing.ImageIcon(getClass().getResource("/images/down.gif")));
        down.setToolTipText("down");
        down.setBorder(null);
        down.setBorderPainted(false);
        down.setContentAreaFilled(false);
        down.setFocusPainted(false);
        down.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                downActionPerformed(evt);
            }
        });

        atf.setText("AT&F");
        atf.setToolTipText("Reset modem to factory settings");
        atf.setMargin(new java.awt.Insets(2, 0, 2, 0));
        atf.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                atfActionPerformed(evt);
            }
        });

        atv.setText("ATV0");
        atv.setToolTipText("Set reply mode to numeric format (0=OK)");
        atv.setMargin(new java.awt.Insets(2, 0, 2, 0));
        atv.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                atvActionPerformed(evt);
            }
        });

        atx.setText("ATX0");
        atx.setToolTipText("Disable detection dial-tone or busy-tone");
        atx.setMargin(new java.awt.Insets(2, 0, 2, 0));
        atx.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                atxActionPerformed(evt);
            }
        });

        atd.setText("AT&D0");
        atd.setToolTipText("Ignore status of DTR mode");
        atd.setMargin(new java.awt.Insets(2, 0, 2, 0));
        atd.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                atdActionPerformed(evt);
            }
        });

        ats.setText("ATS0=1");
        ats.setToolTipText("Automatically answer calls after 1 ring");
        ats.setMargin(new java.awt.Insets(2, 0, 2, 0));
        ats.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                atsActionPerformed(evt);
            }
        });

        atw.setText("AT&W0");
        atw.setToolTipText("Save settings");
        atw.setMargin(new java.awt.Insets(2, 0, 2, 0));
        atw.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                atwActionPerformed(evt);
            }
        });

        atcmgf.setText("AT+CMGF=1");
        atcmgf.setToolTipText("Set SMS to text mode");
        atcmgf.setMargin(new java.awt.Insets(2, 0, 2, 0));
        atcmgf.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                atcmgfActionPerformed(evt);
            }
        });

        command.setText("ATI");
        command.setToolTipText("Enter an AT command");

        atcommand.setText("Send Command");
        atcommand.setToolTipText("Send manual command");
        atcommand.setMargin(new java.awt.Insets(2, 0, 2, 0));
        atcommand.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                atcommandActionPerformed(evt);
            }
        });

        pin.setText("Send PIN");
        pin.setToolTipText("Send SIM PIN");
        pin.setMargin(new java.awt.Insets(2, 0, 2, 0));
        pin.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                pinActionPerformed(evt);
            }
        });

        pincode.setHorizontalAlignment(javax.swing.JTextField.CENTER);
        pincode.setText("0000");
        pincode.setToolTipText("Enter SIM PIN");

        puc.setText("Send PUC");
        puc.setToolTipText("Send SIM PUC to unlock SIM");
        puc.setMargin(new java.awt.Insets(2, 0, 2, 0));
        puc.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                pucActionPerformed(evt);
            }
        });

        puccode.setHorizontalAlignment(javax.swing.JTextField.CENTER);
        puccode.setText("00000000");
        puccode.setToolTipText("Enter PUC to unlock SIM - WARNING WRONG PUC WILL DISABLE SIM CARD");

        autocops.setText("Auto COPS");
        autocops.setToolTipText("Enable automatic network login after 6 sec.");
        autocops.setMargin(new java.awt.Insets(2, 0, 2, 0));
        autocops.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                autocopsActionPerformed(evt);
            }
        });

        disablecops.setText("Disable COPS");
        disablecops.setToolTipText("Disable this automatic function");
        disablecops.setMargin(new java.awt.Insets(2, 0, 2, 0));
        disablecops.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                disablecopsActionPerformed(evt);
            }
        });

        atd2.setText("AT&D2");
        atd2.setToolTipText("ON->OFF on DTR: Disconnect data call, change to command mode.");
        atd2.setMargin(new java.awt.Insets(2, 0, 2, 0));
        atd2.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                atd2ActionPerformed(evt);
            }
        });

        atcops.setText("AT+COPS?");
        atcops.setToolTipText("Displays selected network operator");
        atcops.setMargin(new java.awt.Insets(2, 0, 2, 0));
        atcops.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                atcopsActionPerformed(evt);
            }
        });

        jLabel6.setText("Phonenumber:");

        phonenumber.setHorizontalAlignment(javax.swing.JTextField.CENTER);
        phonenumber.setText("00000000");
        phonenumber.setToolTipText("Enter phonenumber");

        jLabel7.setText("SMS Message:");

        smsmessage.setHorizontalAlignment(javax.swing.JTextField.CENTER);
        smsmessage.setText("TEST SMS");
        smsmessage.setToolTipText("Enter a message");

        sendsms.setText("Send SMS");
        sendsms.setToolTipText("Send SMS");
        sendsms.setMargin(new java.awt.Insets(2, 0, 2, 0));
        sendsms.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                sendsmsActionPerformed(evt);
            }
        });

        servicecenterphonenumber.setHorizontalAlignment(javax.swing.JTextField.CENTER);
        servicecenterphonenumber.setText("00000000");
        servicecenterphonenumber.setToolTipText("Enter servicecenter phonenumber");

        servicephone.setText("Servicecenter");
        servicephone.setToolTipText("Store servicecenter phonenumber");
        servicephone.setMargin(new java.awt.Insets(2, 0, 2, 0));
        servicephone.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                servicephoneActionPerformed(evt);
            }
        });

        autopin.setText("Auto PIN");
        autopin.setToolTipText("Enable automatic PIN after 10 seconds");
        autopin.setMargin(new java.awt.Insets(2, 0, 2, 0));
        autopin.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                autopinActionPerformed(evt);
            }
        });

        autocfun.setText("Auto CFUN");
        autocfun.setToolTipText("Enable automatic restart after 24hr");
        autocfun.setMargin(new java.awt.Insets(2, 0, 2, 0));
        autocfun.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                autocfunActionPerformed(evt);
            }
        });

        disablepin.setText("Disable PIN");
        disablepin.setToolTipText("Disable this automatic function");
        disablepin.setMargin(new java.awt.Insets(2, 0, 2, 0));
        disablepin.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                disablepinActionPerformed(evt);
            }
        });

        disablecfun.setText("Disable CFUN");
        disablecfun.setToolTipText("Disable this automatic function");
        disablecfun.setMargin(new java.awt.Insets(2, 0, 2, 0));
        disablecfun.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                disablecfunActionPerformed(evt);
            }
        });

        powerdown.setText("Power down device");
        powerdown.setToolTipText("Power down the modem and save the auto exec configuration");
        powerdown.setMargin(new java.awt.Insets(2, 0, 2, 0));
        powerdown.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                powerdownActionPerformed(evt);
            }
        });

        ssmss.setText("AT^SSMSS=1");
        ssmss.setToolTipText("Preferred message storage is SIM");
        ssmss.setMargin(new java.awt.Insets(2, 0, 2, 0));
        ssmss.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                ssmssActionPerformed(evt);
            }
        });

        atcmgl.setText("AT+CMGL=ALL");
        atcmgl.setToolTipText("Read all SMS mesages");
        atcmgl.setMargin(new java.awt.Insets(2, 0, 2, 0));
        atcmgl.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                atcmglActionPerformed(evt);
            }
        });

        org.jdesktop.layout.GroupLayout jPanel1Layout = new org.jdesktop.layout.GroupLayout(jPanel1);
        jPanel1.setLayout(jPanel1Layout);
        jPanel1Layout.setHorizontalGroup(
            jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(jPanel1Layout.createSequentialGroup()
                .addContainerGap()
                .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                    .add(jPanel1Layout.createSequentialGroup()
                        .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.TRAILING)
                            .add(org.jdesktop.layout.GroupLayout.LEADING, ssmss, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 94, Short.MAX_VALUE)
                            .add(org.jdesktop.layout.GroupLayout.LEADING, autocfun, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 94, Short.MAX_VALUE)
                            .add(org.jdesktop.layout.GroupLayout.LEADING, jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.TRAILING, false)
                                .add(org.jdesktop.layout.GroupLayout.LEADING, jLabel5, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                                .add(org.jdesktop.layout.GroupLayout.LEADING, atx, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                                .add(org.jdesktop.layout.GroupLayout.LEADING, atcmgf, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                                .add(org.jdesktop.layout.GroupLayout.LEADING, atd, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                                .add(org.jdesktop.layout.GroupLayout.LEADING, atf, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 94, Short.MAX_VALUE))
                            .add(org.jdesktop.layout.GroupLayout.LEADING, autocops, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 94, Short.MAX_VALUE)
                            .add(org.jdesktop.layout.GroupLayout.LEADING, autopin, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 94, Short.MAX_VALUE))
                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                        .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING, false)
                            .add(org.jdesktop.layout.GroupLayout.TRAILING, disablepin, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                            .add(atw, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                            .add(atv, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                            .add(ats, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                            .add(atd2, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                            .add(comport, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 99, Short.MAX_VALUE)
                            .add(disablecops, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                            .add(disablecfun, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                            .add(atcmgl, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED, 10, Short.MAX_VALUE)
                        .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                            .add(org.jdesktop.layout.GroupLayout.TRAILING, jPanel1Layout.createSequentialGroup()
                                .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.TRAILING)
                                    .add(org.jdesktop.layout.GroupLayout.LEADING, jLabel7, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 101, Short.MAX_VALUE)
                                    .add(org.jdesktop.layout.GroupLayout.LEADING, jPanel1Layout.createSequentialGroup()
                                        .add(up, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 16, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                                        .add(0, 0, 0)
                                        .add(down, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 16, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                                    .add(org.jdesktop.layout.GroupLayout.LEADING, servicephone, 0, 0, Short.MAX_VALUE)
                                    .add(org.jdesktop.layout.GroupLayout.LEADING, puc, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 101, Short.MAX_VALUE)
                                    .add(pin, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 101, Short.MAX_VALUE)
                                    .add(jLabel6, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 101, Short.MAX_VALUE)
                                    .add(atcops, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 101, Short.MAX_VALUE))
                                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                                .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                                    .add(smsmessage, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 91, Short.MAX_VALUE)
                                    .add(pincode, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 91, Short.MAX_VALUE)
                                    .add(servicecenterphonenumber, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 91, Short.MAX_VALUE)
                                    .add(phonenumber, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 91, Short.MAX_VALUE)
                                    .add(puccode, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 91, Short.MAX_VALUE)
                                    .add(sendsms, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 91, Short.MAX_VALUE)))
                            .add(org.jdesktop.layout.GroupLayout.TRAILING, powerdown, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 198, Short.MAX_VALUE)))
                    .add(jScrollPane1, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 407, Short.MAX_VALUE)
                    .add(jPanel1Layout.createSequentialGroup()
                        .add(command, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 258, Short.MAX_VALUE)
                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                        .add(atcommand, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 143, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)))
                .addContainerGap())
        );
        jPanel1Layout.setVerticalGroup(
            jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(jPanel1Layout.createSequentialGroup()
                .addContainerGap()
                .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                    .add(jPanel1Layout.createSequentialGroup()
                        .add(jLabel5)
                        .add(15, 15, 15)
                        .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                            .add(atf)
                            .add(atd2)
                            .add(pincode, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                            .add(pin))
                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                        .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                            .add(atcmgf)
                            .add(ats)
                            .add(puc)
                            .add(puccode, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                        .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                            .add(atx)
                            .add(atv)
                            .add(servicephone)
                            .add(servicecenterphonenumber, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                        .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                            .add(atd)
                            .add(atw)
                            .add(phonenumber, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                            .add(jLabel6)))
                    .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                        .add(comport, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                        .add(up)
                        .add(down)))
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(disablecops)
                    .add(autocops)
                    .add(jLabel7)
                    .add(smsmessage, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(atcops)
                    .add(sendsms)
                    .add(disablepin)
                    .add(autopin))
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(autocfun)
                    .add(disablecfun))
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(ssmss)
                    .add(powerdown)
                    .add(atcmgl))
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jScrollPane1, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 150, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(command, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                    .add(atcommand))
                .addContainerGap(org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        org.jdesktop.layout.GroupLayout layout = new org.jdesktop.layout.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(jPanel1, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(jPanel1, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
        );
        pack();
    }// </editor-fold>//GEN-END:initComponents

    private void atcmglActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_atcmglActionPerformed
        sendCommand("AT+CMGL=\"ALL\"");
        readReply();
    }//GEN-LAST:event_atcmglActionPerformed

    private void ssmssActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_ssmssActionPerformed
        sendCommand("AT^SSMSS=1");
        readReply();
    }//GEN-LAST:event_ssmssActionPerformed

    private void powerdownActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_powerdownActionPerformed
        updatemessage("Powering down modem");
        sendCommand("AT^SMSO");
    }//GEN-LAST:event_powerdownActionPerformed

    private void disablecfunActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_disablecfunActionPerformed
        sendCommand("AT^SCFG=\"AutoExec\",0,1,2");
        readReply();
    }//GEN-LAST:event_disablecfunActionPerformed

    private void disablepinActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_disablepinActionPerformed
        sendCommand("AT^SCFG=\"AutoExec\",0,1,1");
        readReply();
    }//GEN-LAST:event_disablepinActionPerformed

    private void autocfunActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_autocfunActionPerformed
        sendCommand("AT^SCFG=\"AutoExec\",1,1,2,0,\"AT+CFUN=1,1\",\"024:00:00\"");        
        readReply();
    }//GEN-LAST:event_autocfunActionPerformed

    private void autopinActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_autopinActionPerformed
        sendCommand("AT^SCFG=\"AutoExec\",1,1,1,0,\"AT+CPIN=" + pincode.getText().toString() + "\",\"000:00:10\"");
        readReply();
        read_delayed_Reply();        
    }//GEN-LAST:event_autopinActionPerformed

    private void servicephoneActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_servicephoneActionPerformed
        sendCommand("AT+CSCA=" + servicecenterphonenumber.getText().toString());
        readReply(); 
    }//GEN-LAST:event_servicephoneActionPerformed

    private void sendsmsActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_sendsmsActionPerformed
        sendCommand("AT+CMGS=" + phonenumber.getText().toString());
        // Wait for the prompt
        try {Thread.sleep(1000);} catch (InterruptedException e) {}
        sendCommand(smsmessage.getText().toString() + "\u001A");
        read_delayed_Reply(); 
    }//GEN-LAST:event_sendsmsActionPerformed

    private void atcopsActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_atcopsActionPerformed
        sendCommand("AT+COPS?");
        readReply(); 
    }//GEN-LAST:event_atcopsActionPerformed

    private void atd2ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_atd2ActionPerformed
        sendCommand("AT&D2");
        readReply(); 
    }//GEN-LAST:event_atd2ActionPerformed

    private void disablecopsActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_disablecopsActionPerformed
        sendCommand("AT^SCFG=\"AutoExec\",0,1,0");
        readReply();     
    }//GEN-LAST:event_disablecopsActionPerformed

    private void autocopsActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_autocopsActionPerformed
        sendCommand("AT^SCFG=\"AutoExec\",1,1,0,0,\"AT+COPS=0\",\"000:00:06\"");
        readReply(); 
        read_delayed_Reply();
    }//GEN-LAST:event_autocopsActionPerformed

    private void pucActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_pucActionPerformed
        sendCommand("AT+CPWD=PS," + puccode.getText().toString());
        readReply();
    }//GEN-LAST:event_pucActionPerformed

    private void pinActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_pinActionPerformed
        sendCommand("AT+CPIN=" + pincode.getText().toString());
        readReply();
    }//GEN-LAST:event_pinActionPerformed

    private void atcommandActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_atcommandActionPerformed
        updatemessage(command.getText().toString());
        sendCommand(command.getText().toString());
        readReply();
    }//GEN-LAST:event_atcommandActionPerformed

    private void atcmgfActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_atcmgfActionPerformed
        sendCommand("AT+CMGF=1");
        readReply();
    }//GEN-LAST:event_atcmgfActionPerformed

    private void atwActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_atwActionPerformed
        sendCommand("AT&W0");
        readReply();
    }//GEN-LAST:event_atwActionPerformed

    private void atsActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_atsActionPerformed
        sendCommand("ATS0=1");
        readReply();
    }//GEN-LAST:event_atsActionPerformed

    private void atdActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_atdActionPerformed
        sendCommand("AT&D0");
        readReply(); 
    }//GEN-LAST:event_atdActionPerformed

    private void atxActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_atxActionPerformed
        sendCommand("ATX0");
        readReply(); 
    }//GEN-LAST:event_atxActionPerformed

    private void atvActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_atvActionPerformed
        sendCommand("ATV0");
        readReply(); 
    }//GEN-LAST:event_atvActionPerformed

    private void atfActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_atfActionPerformed
        sendCommand("AT&F");
        readReply();   
    }//GEN-LAST:event_atfActionPerformed

    private void formWindowClosing(java.awt.event.WindowEvent evt) {//GEN-FIRST:event_formWindowClosing
        closeCOM();
    }//GEN-LAST:event_formWindowClosing

    private void formWindowOpened(java.awt.event.WindowEvent evt) {//GEN-FIRST:event_formWindowOpened
        initializeCOM();
        message.setText("");
    }//GEN-LAST:event_formWindowOpened

    private void downActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_downActionPerformed
        comport.setText("" + (Integer.parseInt(comport.getText())-1));
        if (Integer.parseInt(comport.getText())<1)
            comport.setText("1");
        message.setText("");
        initializeCOM();
    }//GEN-LAST:event_downActionPerformed

    private void upActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_upActionPerformed
        comport.setText("" + (Integer.parseInt(comport.getText())+1));
        message.setText("");
        initializeCOM();
    }//GEN-LAST:event_upActionPerformed
    
    /**
     * @param args the command line arguments
     */
    public static void main(String args[]) {
        java.awt.EventQueue.invokeLater(new Runnable() {
            public void run() {
                new configpanel().setVisible(true);
            }
        });
    }
    
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton atcmgf;
    private javax.swing.JButton atcmgl;
    private javax.swing.JButton atcommand;
    private javax.swing.JButton atcops;
    private javax.swing.JButton atd;
    private javax.swing.JButton atd2;
    private javax.swing.JButton atf;
    private javax.swing.JButton ats;
    private javax.swing.JButton atv;
    private javax.swing.JButton atw;
    private javax.swing.JButton atx;
    private javax.swing.JButton autocfun;
    private javax.swing.JButton autocops;
    private javax.swing.JButton autopin;
    private javax.swing.JTextField command;
    private javax.swing.JTextField comport;
    private javax.swing.JButton disablecfun;
    private javax.swing.JButton disablecops;
    private javax.swing.JButton disablepin;
    private javax.swing.JButton down;
    private javax.swing.JLabel jLabel5;
    private javax.swing.JLabel jLabel6;
    private javax.swing.JLabel jLabel7;
    private javax.swing.JPanel jPanel1;
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JTextArea message;
    private javax.swing.JTextField phonenumber;
    private javax.swing.JButton pin;
    private javax.swing.JTextField pincode;
    private javax.swing.JButton powerdown;
    private javax.swing.JButton puc;
    private javax.swing.JTextField puccode;
    private javax.swing.JButton sendsms;
    private javax.swing.JTextField servicecenterphonenumber;
    private javax.swing.JButton servicephone;
    private javax.swing.JTextField smsmessage;
    private javax.swing.JButton ssmss;
    private javax.swing.JButton up;
    // End of variables declaration//GEN-END:variables
    
}
